# QSpaceHessian API Reference

::: tdscha.QSpaceHessian
    options:
        show_root_heading: true
        show_source: true
        heading_level: 2
        members_order: source
        filters: ["!^_"]
